@@ -16,32 +16,36 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.recommender_v1.services.recommender import pagers
-from google.cloud.recommender_v1.types import insight
-from google.cloud.recommender_v1.types import recommendation
-from google.cloud.recommender_v1.types import recommender_service
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import struct_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import RecommenderTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.recommender_v1.services.recommender import pagers
+from google.cloud.recommender_v1.types import (
+    insight,
+    recommendation,
+    recommender_service,
+)
+
+from .transports.base import DEFAULT_CLIENT_INFO, RecommenderTransport
 from .transports.grpc import RecommenderGrpcTransport
 from .transports.grpc_asyncio import RecommenderGrpcAsyncIOTransport
 
@@ -58,7 +62,10 @@ class RecommenderClientMeta(type):
     _transport_registry["grpc"] = RecommenderGrpcTransport
     _transport_registry["grpc_asyncio"] = RecommenderGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[RecommenderTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[RecommenderTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -169,7 +176,10 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def insight_path(
-        project: str, location: str, insight_type: str, insight: str,
+        project: str,
+        location: str,
+        insight_type: str,
+        insight: str,
     ) -> str:
         """Returns a fully-qualified insight string."""
         return "projects/{project}/locations/{location}/insightTypes/{insight_type}/insights/{insight}".format(
@@ -189,10 +199,16 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def insight_type_path(project: str, location: str, insight_type: str,) -> str:
+    def insight_type_path(
+        project: str,
+        location: str,
+        insight_type: str,
+    ) -> str:
         """Returns a fully-qualified insight_type string."""
         return "projects/{project}/locations/{location}/insightTypes/{insight_type}".format(
-            project=project, location=location, insight_type=insight_type,
+            project=project,
+            location=location,
+            insight_type=insight_type,
         )
 
     @staticmethod
@@ -206,7 +222,10 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def recommendation_path(
-        project: str, location: str, recommender: str, recommendation: str,
+        project: str,
+        location: str,
+        recommender: str,
+        recommendation: str,
     ) -> str:
         """Returns a fully-qualified recommendation string."""
         return "projects/{project}/locations/{location}/recommenders/{recommender}/recommendations/{recommendation}".format(
@@ -226,10 +245,18 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def recommender_path(project: str, location: str, recommender: str,) -> str:
+    def recommender_path(
+        project: str,
+        location: str,
+        recommender: str,
+    ) -> str:
         """Returns a fully-qualified recommender string."""
-        return "projects/{project}/locations/{location}/recommenders/{recommender}".format(
-            project=project, location=location, recommender=recommender,
+        return (
+            "projects/{project}/locations/{location}/recommenders/{recommender}".format(
+                project=project,
+                location=location,
+                recommender=recommender,
+            )
         )
 
     @staticmethod
@@ -242,7 +269,9 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -255,9 +284,13 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -266,9 +299,13 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -277,9 +314,13 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -288,10 +329,14 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -478,7 +523,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         recommender.*.list IAM permission for the specified insight
         type.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1
@@ -571,12 +615,20 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListInsightsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -594,7 +646,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Gets the requested insight. Requires the recommender.*.get IAM
         permission for the specified insight type.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1
@@ -668,7 +719,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -678,9 +734,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         request: Union[recommender_service.MarkInsightAcceptedRequest, dict] = None,
         *,
         name: str = None,
-        state_metadata: Sequence[
-            recommender_service.MarkInsightAcceptedRequest.StateMetadataEntry
-        ] = None,
+        state_metadata: Mapping[str, str] = None,
         etag: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -695,7 +749,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified insight.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1
@@ -725,7 +778,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (Sequence[google.cloud.recommender_v1.types.MarkInsightAcceptedRequest.StateMetadataEntry]):
+            state_metadata (Mapping[str, str]):
                 Optional. State properties user wish to include with
                 this state. Full replace of the current state_metadata.
 
@@ -789,7 +842,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -808,7 +866,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         the recommender.*.list IAM permission for the specified
         recommender.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1
@@ -929,12 +986,20 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListRecommendationsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -952,7 +1017,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Gets the requested recommendation. Requires the
         recommender.*.get IAM permission for the specified recommender.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1
@@ -1027,7 +1091,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1039,9 +1108,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         ] = None,
         *,
         name: str = None,
-        state_metadata: Sequence[
-            recommender_service.MarkRecommendationClaimedRequest.StateMetadataEntry
-        ] = None,
+        state_metadata: Mapping[str, str] = None,
         etag: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -1059,7 +1126,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified recommender.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1
@@ -1089,7 +1155,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (Sequence[google.cloud.recommender_v1.types.MarkRecommendationClaimedRequest.StateMetadataEntry]):
+            state_metadata (Mapping[str, str]):
                 State properties to include with this state. Overwrites
                 any existing ``state_metadata``. Keys must match the
                 regex ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must
@@ -1160,7 +1226,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1172,9 +1243,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         ] = None,
         *,
         name: str = None,
-        state_metadata: Sequence[
-            recommender_service.MarkRecommendationSucceededRequest.StateMetadataEntry
-        ] = None,
+        state_metadata: Mapping[str, str] = None,
         etag: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -1192,7 +1261,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified recommender.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1
@@ -1222,7 +1290,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (Sequence[google.cloud.recommender_v1.types.MarkRecommendationSucceededRequest.StateMetadataEntry]):
+            state_metadata (Mapping[str, str]):
                 State properties to include with this state. Overwrites
                 any existing ``state_metadata``. Keys must match the
                 regex ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must
@@ -1293,7 +1361,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1305,9 +1378,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         ] = None,
         *,
         name: str = None,
-        state_metadata: Sequence[
-            recommender_service.MarkRecommendationFailedRequest.StateMetadataEntry
-        ] = None,
+        state_metadata: Mapping[str, str] = None,
         etag: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -1325,7 +1396,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified recommender.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1
@@ -1355,7 +1425,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (Sequence[google.cloud.recommender_v1.types.MarkRecommendationFailedRequest.StateMetadataEntry]):
+            state_metadata (Mapping[str, str]):
                 State properties to include with this state. Overwrites
                 any existing ``state_metadata``. Keys must match the
                 regex ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must
@@ -1424,7 +1494,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
